/****************************************************************************
** Meta object code from reading C++ file 'k3bdatajob.h'
**
** Created by: The Qt Meta Object Compiler version 69 (Qt 6.11.0)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include "../../../../k3b-26.04.1/libk3b/projects/datacd/k3bdatajob.h"
#include <QtCore/qmetatype.h>

#include <QtCore/qtmochelpers.h>

#include <memory>


#include <QtCore/qxptype_traits.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'k3bdatajob.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 69
#error "This file was generated using the moc from 6.11.0. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

#ifndef Q_CONSTINIT
#define Q_CONSTINIT
#endif

QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wuseless-cast")
namespace {
struct qt_meta_tag_ZN3K3b7DataJobE_t {};
} // unnamed namespace

template <> constexpr inline auto K3b::DataJob::qt_create_metaobjectdata<qt_meta_tag_ZN3K3b7DataJobE_t>()
{
    namespace QMC = QtMocConstants;
    QtMocHelpers::StringRefStorage qt_stringData {
        "K3b::DataJob",
        "cancel",
        "",
        "start",
        "setWriterJob",
        "AbstractWriter*",
        "setImager",
        "IsoImager*",
        "slotIsoImagerFinished",
        "success",
        "slotIsoImagerPercent",
        "slotWriterJobPercent",
        "p",
        "slotWriterNextTrack",
        "t",
        "tt",
        "slotWriterJobFinished",
        "slotVerificationProgress",
        "slotVerificationFinished",
        "writeImage",
        "cancelAll",
        "slotMultiSessionParamterSetupDone"
    };

    QtMocHelpers::UintData qt_methods {
        // Slot 'cancel'
        QtMocHelpers::SlotData<void()>(1, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'start'
        QtMocHelpers::SlotData<void()>(3, 2, QMC::AccessPublic, QMetaType::Void),
        // Slot 'setWriterJob'
        QtMocHelpers::SlotData<void(AbstractWriter *)>(4, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 5, 2 },
        }}),
        // Slot 'setImager'
        QtMocHelpers::SlotData<void(IsoImager *)>(6, 2, QMC::AccessPublic, QMetaType::Void, {{
            { 0x80000000 | 7, 2 },
        }}),
        // Slot 'slotIsoImagerFinished'
        QtMocHelpers::SlotData<void(bool)>(8, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotIsoImagerPercent'
        QtMocHelpers::SlotData<void(int)>(10, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotWriterJobPercent'
        QtMocHelpers::SlotData<void(int)>(11, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 12 },
        }}),
        // Slot 'slotWriterNextTrack'
        QtMocHelpers::SlotData<void(int, int)>(13, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 14 }, { QMetaType::Int, 15 },
        }}),
        // Slot 'slotWriterJobFinished'
        QtMocHelpers::SlotData<void(bool)>(16, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 9 },
        }}),
        // Slot 'slotVerificationProgress'
        QtMocHelpers::SlotData<void(int)>(17, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Int, 2 },
        }}),
        // Slot 'slotVerificationFinished'
        QtMocHelpers::SlotData<void(bool)>(18, 2, QMC::AccessProtected, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
        // Slot 'writeImage'
        QtMocHelpers::SlotData<void()>(19, 2, QMC::AccessProtected, QMetaType::Void),
        // Slot 'cancelAll'
        QtMocHelpers::SlotData<bool()>(20, 2, QMC::AccessProtected, QMetaType::Bool),
        // Slot 'slotMultiSessionParamterSetupDone'
        QtMocHelpers::SlotData<void(bool)>(21, 2, QMC::AccessPrivate, QMetaType::Void, {{
            { QMetaType::Bool, 2 },
        }}),
    };
    QtMocHelpers::UintData qt_properties {
    };
    QtMocHelpers::UintData qt_enums {
    };
    return QtMocHelpers::metaObjectData<DataJob, qt_meta_tag_ZN3K3b7DataJobE_t>(QMC::MetaObjectFlag{}, qt_stringData,
            qt_methods, qt_properties, qt_enums);
}
Q_CONSTINIT const QMetaObject K3b::DataJob::staticMetaObject = { {
    QMetaObject::SuperData::link<BurnJob::staticMetaObject>(),
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b7DataJobE_t>.stringdata,
    qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b7DataJobE_t>.data,
    qt_static_metacall,
    nullptr,
    qt_staticMetaObjectRelocatingContent<qt_meta_tag_ZN3K3b7DataJobE_t>.metaTypes,
    nullptr
} };

void K3b::DataJob::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    auto *_t = static_cast<DataJob *>(_o);
    if (_c == QMetaObject::InvokeMetaMethod) {
        switch (_id) {
        case 0: _t->cancel(); break;
        case 1: _t->start(); break;
        case 2: _t->setWriterJob((*reinterpret_cast<std::add_pointer_t<AbstractWriter*>>(_a[1]))); break;
        case 3: _t->setImager((*reinterpret_cast<std::add_pointer_t<IsoImager*>>(_a[1]))); break;
        case 4: _t->slotIsoImagerFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 5: _t->slotIsoImagerPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 6: _t->slotWriterJobPercent((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 7: _t->slotWriterNextTrack((*reinterpret_cast<std::add_pointer_t<int>>(_a[1])),(*reinterpret_cast<std::add_pointer_t<int>>(_a[2]))); break;
        case 8: _t->slotWriterJobFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 9: _t->slotVerificationProgress((*reinterpret_cast<std::add_pointer_t<int>>(_a[1]))); break;
        case 10: _t->slotVerificationFinished((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        case 11: _t->writeImage(); break;
        case 12: { bool _r = _t->cancelAll();
            if (_a[0]) *reinterpret_cast<bool*>(_a[0]) = std::move(_r); }  break;
        case 13: _t->slotMultiSessionParamterSetupDone((*reinterpret_cast<std::add_pointer_t<bool>>(_a[1]))); break;
        default: ;
        }
    }
}

const QMetaObject *K3b::DataJob::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *K3b::DataJob::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_staticMetaObjectStaticContent<qt_meta_tag_ZN3K3b7DataJobE_t>.strings))
        return static_cast<void*>(this);
    return BurnJob::qt_metacast(_clname);
}

int K3b::DataJob::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = BurnJob::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 14)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 14;
    }
    if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 14)
            *reinterpret_cast<QMetaType *>(_a[0]) = QMetaType();
        _id -= 14;
    }
    return _id;
}
QT_WARNING_POP
